/**
 * Copyright © 2010 Nokia Corporation. All rights reserved. Nokia and Nokia Connecting People
 * are registered trademarks of Nokia Corporation. Java and all Java-based marks are trademarks
 * or registered trademarks of Sun Microsystems, Inc. Other product and company names mentioned herein
 * may be trademarks or trade names of their respective owners.
 *
 * Subject to the conditions below, you may, without charge:
 *  - Use, copy, modify and/or merge copies of this software and associated documentation files (the "Software")
 *  - Publish, distribute, sub-license and/or sell new software derived from or incorporating the Software.
 *
 * This license, unmodified, shall be included with all copies or substantial portions of the Software
 * that are distributed in source code form.
 *
 * The Software cannot constitute the primary value of any new software derived from or incorporating the Software.
 * Any person dealing with the Software shall not misrepresent the source of the Software.
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
 * AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import javax.microedition.io.Connector;
import javax.microedition.io.file.FileConnection;

/**
 * File based storage using JSR-75.
 */
public class FileRms implements RmsConnection  {
    private String rootDir;
    private String rmsName = "FileRms";
    FileConnection fc;

    public FileRms() {
        rootDir = System.getProperty("fileconn.dir.private");
    }

    public void open() {
        try {
            fc = (FileConnection) Connector.open(rootDir + rmsName);
            if (!fc.exists()) {
                fc.create();
            }
        } catch(IOException e) {
            e.printStackTrace();
        }
    }

    public byte[] get() {
        byte[] data = null;
        try {
            InputStream is = fc.openInputStream();

            int len = (int)fc.fileSize();
            data = new byte[len];
            int readBytes = is.read(data);
            if (readBytes != len) {
                System.out.println("read size mismatch");
            }

            is.close();
        } catch(IOException e) {
            e.printStackTrace();
        }
        return data;
    }

    public void set(byte[] data) {
        try {
            OutputStream os = fc.openOutputStream();
            os.write(data);
            os.close();
        } catch(IOException e) {
            e.printStackTrace();
        }
    }
    public void close() {
        try {
            fc.close();
        } catch(IOException e) {
            e.printStackTrace();
        }
    }

    public void delete() {
        try {
            FileConnection file = (FileConnection) Connector.open(rootDir + rmsName);
            if (file.exists()) {
                file.delete();
            }
            file.close();
        } catch(IOException e) {
            e.printStackTrace();
        }
    }

}
